@@ -210,14 +210,14 @@ string csisearch::derive_formula(distr& dist) {
             if ( dist.primitive ) formula = to_string(dist.pp);
             else {
                 if ( rsq == 4 ) {
-                    if ( paf1.length() < paf2.length() ) formula = paf1 + "*" + paf2;
-                    else formula = paf2 + "*" + paf1;
+                    if ( paf1.length() < paf2.length() ) formula = "\\left(" + paf1 + paf2  + "\\right)";
+                    else formula = "\\left(" + paf2 + paf1 + "\\right)";
                 } else if ( rsq == 25 ) {
-                    formula = "[" + paf1 + " /\\ " + paf2 + "]";
+                    formula = "\\left[" + paf1 + " /\\ " + paf2 + "\\right]";
                 } else if ( rsq == 36 ) {
-                    formula = "[" + paf2 + " - " + paf1 + "]";
+                    formula = "\\left(" + paf2 + " - " + paf1 + "\\right)";
                 } else if ( rsq == 49 ) {
-                    formula = "[" + paf1 + " - " + paf2 + "]";
+                    formula = "\\left(" + paf1 + " - " + paf2 + "\\right)";
                 }
             }
         } else {
@@ -227,15 +227,15 @@ string csisearch::derive_formula(distr& dist) {
                 if ( dist.primitive ) formula = to_string(dist.pp);
                 else {
                     if ( rsq == 0 ) {
-                        formula =  "[sum_{" + dec_to_text(pa1.pp.a - dist.pp.a, 0, 0) + "}" + paf1 + "]";
+                        formula =  "\\sum_{" + dec_to_text(pa1.pp.a - dist.pp.a, 0, 0) + "}" + paf1;
                     } else if ( rsq == 1 ) {
-                        formula = "[[" + paf1 + "]/[sum_{" + dec_to_text(dist.pp.a, 0, 0) + "} " + paf1 + "]]";
+                        formula = "\\frac{" + paf1 + "}{\\sum_{" + dec_to_text(dist.pp.a, 0, 0) + "} " + paf1 + "}";
                     } else if ( rsq == 64 ) {
                         if ( dist.pp.c - pa1.pp.c > 0 ) {
-                            formula = "[" + paf1 + "]_{" + dec_to_text(dist.pp.c - pa1.pp.c, 0, 0) + " = 0}";
+                            formula = "\\left[" + paf1 + "\\right]_{" + dec_to_text(dist.pp.c - pa1.pp.c, 0, 0) + " = 0}";
                         }
                         else if ( dist.pp.d - pa1.pp.d > 0 ) {
-                            formula = "[" + paf1 + "]_{" + dec_to_text(dist.pp.d - pa1.pp.d, 0, 0) + " = 1}";
+                            formula = "\\left[" + paf1 + "\\right]_{" + dec_to_text(dist.pp.d - pa1.pp.d, 0, 0) + " = 1}";
                         }
                     }
                 }
